%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code is for the Christiano-Ikeda project
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@# define financial_data = ["empty" ]

% Depending on the variables included in the financial data, we need some
% indicator variables.

@# include "cmr_indicator_variables.mod"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0. Housekeeping, paths, and estimation decisions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
addpath('../dynare_code');
addpath('..');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. Declaration of variables and parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%cee = 2 means the christiano-ikeda model
%cee = 1 means cee model
@#define cee = 2
@# include "../cmr_declarations.mod"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2. Set parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% when stopshock = 0, then non-risk shocks are all turned off
@# define stopshock = 1

% when stopsignal = 0, then signals on risk are turned off
@# define stopsignal = 1

% when stopunant = 0, then unanticipated risk shock turned off
@# define stopunant = 1

% when par8nonzero = 1, par8 can be non zero.  Otherwise, set to zero
@# define par8nonzero = 1

@# include "../cmr_parameters.mod"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3. Model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@# include "../cmr_model.mod"

% Compute the steady state of the model.
steady;

% Compute the eigenvalues of the model linearized around the steady state.
check;

% Specifiy the shocks.
@# include "../cmr_shocks.mod"

% List all parameters to be estimated and prior
@# include "../cmr_estimated_params.mod"

% Declare numerical initial values for the optimizer.
@# include "../cmr_estimated_params_init.mod"

@# if cee == 1
load cmr_mode_cee;
@# endif

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 5. Stochastic Simulation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

stoch_simul(order = 1, irf = 16, nograph);

tt=1:length(Re_e_xp);
@# if cee == 1
  Ntil_e_xp=zeros(length(tt),1);
  leverage_e_xp=zeros(length(tt),1);
  bankspread_e_xp=zeros(length(tt),1);
  gam_e_xp=zeros(length(tt),1);
  vz_e_xp=zeros(length(tt),1);
  cross_std_e_xp=zeros(length(tt),1);
  e_e_xp=zeros(length(tt),1);

  Ntil_e_epsil=zeros(length(tt),1);
  leverage_e_epsil=zeros(length(tt),1);
  bankspread_e_epsil=zeros(length(tt),1);
  gam_e_epsil=zeros(length(tt),1);
  vz_e_epsil=zeros(length(tt),1);
  cross_std_e_epsil=zeros(length(tt),1);
  e_e_epsil=zeros(length(tt),1);
@# endif

//nothing is done with the cee model!
@# if cee ==1
  return;
@# endif

figure('name','epsil shock')
plott(dtil_e_epsil,q_e_epsil,Rk_e_epsil,Rdg_e_epsil,cross_std_e_epsil,kbar_e_epsil,h_e_epsil,s_e_epsil,wtilde_e_epsil,rk_e_epsil,e_e_epsil,kshock_e_epsil,Re_e_epsil,Ntil_e_epsil,leverage_e_epsil,bankspread_e_epsil,gam_e_epsil,c_e_epsil,i_e_epsil,g_e_epsil,vz_e_epsil,pi_e_epsil,M_.endo_names,oo_.steady_state,M_.param_names,M_.params);

figure('name','25APR policy shock')
plott(dtil_e_xp,q_e_xp,Rk_e_xp,Rdg_e_xp,cross_std_e_xp,kbar_e_xp,h_e_xp,s_e_xp,wtilde_e_xp,rk_e_xp,e_e_xp,kshock_e_xp,Re_e_xp,Ntil_e_xp,leverage_e_xp,bankspread_e_xp,gam_e_xp,c_e_xp,i_e_xp,g_e_xp,vz_e_xp,pi_e_xp,M_.endo_names,oo_.steady_state,M_.param_names,M_.params);


figure('name','gam shock')
plott(dtil_eta_gam,q_eta_gam,Rk_eta_gam,Rdg_eta_gam,cross_std_eta_gam,kbar_eta_gam,h_eta_gam,s_eta_gam,wtilde_eta_gam,rk_eta_gam,e_eta_gam,kshock_eta_gam,Re_eta_gam,Ntil_eta_gam,leverage_eta_gam,bankspread_eta_gam,gam_eta_gam,c_eta_gam,i_eta_gam,g_eta_gam,vz_eta_gam,pi_eta_gam,M_.endo_names,oo_.steady_state,M_.param_names,M_.params);
figure('name','risk shock')
plott(dtil_eta_risk,q_eta_risk,Rk_eta_risk,Rdg_eta_risk,cross_std_eta_risk,kbar_eta_risk,h_eta_risk,s_eta_risk,wtilde_eta_risk,rk_eta_risk,e_eta_risk,kshock_eta_risk,Re_eta_risk,Ntil_eta_risk,leverage_eta_risk,bankspread_eta_risk,gam_eta_risk,c_eta_risk,i_eta_risk,g_eta_risk,vz_eta_risk,pi_eta_risk,M_.endo_names,oo_.steady_state,M_.param_names,M_.params);
figure('name','T shock')
plott(dtil_eta_Ttil,q_eta_Ttil,Rk_eta_Ttil,Rdg_eta_Ttil,cross_std_eta_Ttil,kbar_eta_Ttil,h_eta_Ttil,s_eta_Ttil,wtilde_eta_Ttil,rk_eta_Ttil,e_eta_Ttil,kshock_eta_Ttil,Re_eta_Ttil,Ntil_eta_Ttil,leverage_eta_Ttil,bankspread_eta_Ttil,gam_eta_Ttil,c_eta_Ttil,i_eta_Ttil,g_eta_Ttil,vz_eta_Ttil,pi_eta_Ttil,M_.endo_names,oo_.steady_state,M_.param_names,M_.params);

figure('name','policy_manuscript')
plott_manuscript(leverage_e_xp,dtil_e_xp,cross_std_e_xp,e_e_xp,Re_e_xp,Ntil_e_xp,bankspread_e_xp,gam_e_xp, ...
    c_e_xp,i_e_xp,g_e_xp,pi_e_xp,M_.endo_names,oo_.steady_state,M_.param_names,M_.params)
figure('name','gam_manuscript')
plott_manuscript(leverage_eta_gam,dtil_eta_gam,cross_std_eta_gam,e_eta_gam,Re_eta_gam,Ntil_eta_gam,bankspread_eta_gam,gam_eta_gam, ...
    c_eta_gam,i_eta_gam,g_eta_gam,pi_eta_gam,M_.endo_names,oo_.steady_state,M_.param_names,M_.params)
figure('name','risk_manuscript')
plott_manuscript(leverage_eta_risk,dtil_eta_risk,cross_std_eta_risk,e_eta_risk,Re_eta_risk,Ntil_eta_risk,bankspread_eta_risk,gam_eta_risk, ...
    c_eta_risk,i_eta_risk,g_eta_risk,pi_eta_risk,M_.endo_names,oo_.steady_state,M_.param_names,M_.params)
figure('name','Ttil_manuscript')
plott_manuscript(leverage_eta_Ttil,dtil_eta_Ttil,cross_std_eta_Ttil,e_eta_Ttil,Re_eta_Ttil,Ntil_eta_Ttil,bankspread_eta_Ttil,gam_eta_Ttil, ...
    c_eta_Ttil,i_eta_Ttil,g_eta_Ttil,pi_eta_Ttil,M_.endo_names,oo_.steady_state,M_.param_names,M_.params)


