load data_BAAoverTB
tt=1981:1/4:2010+1/4;
[Y,I]=min(abs(tt-(2001+2/4)));
tt=I:length(tt);

% these are the variables in data_BAAoverTB.mat:
%Re_obs          consumption_obs  gdp_obs          inflation_obs    networth_obs     premium_obs      
%Spread1_obs     credit_obs       hours_obs        investment_obs   pinvest_obs      wage_obs 

fprintf(' standard deviation of quarterly growth rates\n')
fprintf(' gdp = %7.5f, consumption = %7.5f, investment = %7.5f, networth = %7.5f, wage = %7.5f, credit = %7.5f, investment price = %7.5f\n', ...
    std(log(gdp_obs(tt))),std(log(consumption_obs(tt))),std(log(investment_obs(tt))),std(log(networth_obs(tt))),std(log(wage_obs(tt))), ...
    std(log(credit_obs(tt))),std(log(pinvest_obs(tt))))
fprintf(' standard deviation of levels\n')
fprintf(' risk-free rate = %7.5f, inflation = %7.5f, premium = %7.5f, spread = %7.5f, hours = %7.5f\n', ...
    std(log(Re_obs(tt))),std(log(inflation_obs(tt))),std(log(premium_obs(tt))),std(log(Spread1_obs(tt))),std(log(hours_obs(tt))))

gdp=log(gdp_obs);
cons=log(consumption_obs);
inv=log(investment_obs);
equity=log(networth_obs);
hours=log(hours_obs);
wage=log(wage_obs);

A=zeros(6,12);
JJ=[tt(1):tt(end)-12];
lg=36;
for ii=JJ
    mgdp=mean(gdp(ii-lg:ii));
    mcons=mean(cons(ii-lg:ii));
    minv=mean(inv(ii-lg:ii));
    mequity=mean(equity(ii-lg:ii));
    mhours=mean(hours(ii-lg:ii));
    mwage=mean(wage(ii-lg:ii));
    for jj = 1:12
        A(1,jj)=A(1,jj)+(gdp(ii+jj)-mgdp)^2;
        A(2,jj)=A(2,jj)+(cons(ii+jj)-mcons)^2;
        A(3,jj)=A(3,jj)+(inv(ii+jj)-minv)^2;
        A(4,jj)=A(4,jj)+(equity(ii+jj)-mequity)^2;
        A(5,jj)=A(5,jj)+(hours(ii+jj)-mhours)^2;
        A(6,jj)=A(6,jj)+(wage(ii+jj)-mwage)^2;
    end
end
A=100*sqrt(A/length(JJ));
fprintf(' RMSE results for forecast based on mean over most recent %2.0i quarters\n',lg)
fprintf(' gdp for j=1,...,12 = %5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f\n',A(1,:))
fprintf(' cons for j=1,...,12 = %5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f\n',A(2,:))
fprintf(' inv for j=1,...,12 = %5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f\n',A(3,:))
fprintf(' equity for j=1,...,12 = %5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f\n',A(4,:))
fprintf(' hours for j=1,...,12 = %5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f\n',A(5,:))
fprintf(' wage for j=1,...,12 = %5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f,%5.2f\n',A(6,:))



