clear all;
close all
dbstop if error

% this program constructs the tables for the paper (don't worry about warning signs generated by the program).
% the parameter, tab, is set to zero to avoid unintentional overwriting of the
% tables. To rewrite the tables, set tab to 1. When the tables
% have been written, they can be found in the Scientific Word document, steady_a.tex

tab=0;

%// model parameters	 

xiw_p          =   0.75;
xip_p          =   0.75;
b_p            =   0.735843822700000  ;	 
sigmaa_p       =   253.5553419500000  ;	 
Sdoupr_p       =   5.000000003400000  ;
iota1_p        =   1  ;	%weight on steady state inflation in price updating 
iotaw1_p       =   1  ;	%weight on steady state inflation in wage updating

bbar_p            = 0.3;
alpha_p           = 0.4;
aptil_p           = 1.5;
adytil_p          = 0.5 ;	 
rhotil_p          = 0.8;	
beta_p            = 0.998704208591811;
delta_p           = 0.025;
epsil_p           = 1;
etag_p            = 0.20;
gam_p             = 0.85;
lambdaf_p         = 1.2;
lambdaw_p         = 1.05;
muup_p            = 1;
muzstar_p         = 1.004124413586981;
pi_p              = 1.006010795406775;
pibar_p           = 1.006010795406775;
pitarget_p        = 1.006010795406775;
psiL_p            = 1;
sigmaL_p          = 1;
upsil_p           = 1.004223171829000;
zeta_p            = 1;
zetac_p           = 1;
zetai_p           = 1;
psik_p            = 0;

%// Calibrated parameters.
L_cb           = 20;
spread_cb      = .6/400;
sdb_cb         = .2;
LL_constr      = [20 17];

%bbar_p=.1775;%highest bbar_p for which unobserved effort equilibrium exists..however leverage restriction reduces welfare.

[xzetac,xq,xu,xwstar,xpstar,xkbar,xs,xRe,xRk,xrk,xwtilde,xh,xyz,xc,xi,xg,xlambdaz,xphi_p,xFp,xFw,xNtil,xT_p,xpe,xbstar_p, ...
    xgstar_p,xe,xabar_p,xRdg,xRdb,xdtil,xvz,xeta,xRg,xRb] = ...
    hidden_effort_steady(bbar_p,L_cb,spread_cb,sdb_cb,pi_p,lambdaf_p,epsil_p,muzstar_p,beta_p,etag_p,upsil_p,delta_p, ...
    alpha_p,b_p,lambdaw_p,psiL_p,sigmaL_p,psik_p,muup_p,xip_p,xiw_p,zetai_p,gam_p,zetac_p);

abar_p=xabar_p;
bstar_p=xbstar_p;
gstar_p=xgstar_p;
Ttil_p=xT_p;

g=xg;
phi_p=xphi_p;
h_guess=xh;

obs=1;

if obs==1
    
    if length(LL_constr) ~= 2
        error('fatal (steady_state_leverage) LL_constr does not have two elements in it')
    end
    
    %first, consider the case of observed effort and no leverage constraint..
    
    R=muzstar_p*pi_p/beta_p;
    Ntilde=Ttil_p/(1-(gam_p/(muzstar_p*pi_p))*R);
    s=1/lambdaf_p;
    
    [yutil,pe,ye,dtilde,kbar,i,c,lambdaz,Rk,rk,wtilde,h] = oobserve_pe(Ntilde,xpe,alpha_p,b_p,g,h_guess, ...
        abar_p,bbar_p,muzstar_p,pi_p,gstar_p,bstar_p,delta_p,upsil_p,phi_p,muup_p,beta_p,lambdaw_p,psiL_p,sigmaL_p,R,s);
    
    %now, compute the observed effort model with leverage constraints....
    %this is leverage in the observed e model with no leverage constraints
    kshock=pe*exp(gstar_p)+(1-pe)*exp(bstar_p);
    L=(Ntilde+dtilde)/Ntilde;
    utility(3)=0;
    sspread(3)=0;
    vvz(3)=0;
    kkbar(3)=kbar;
    hh(3)=h;
    aa(3)=Ntilde+dtilde;
    NN(3)=Ntilde;
    DD(3)=dtilde;
    nret(3)=kshock*Rk;
    dret(3)=(kshock*Rk-R)*(L-1);
    ret(3)=nret(3)+dret(3);
    RRk(3)=Rk;
    be(3)=kshock;
    gdp(3)=c+i+g;
    ppe(3)=pe;    
    ut(3)=yutil-((pe-abar_p)/bbar_p)^2/2;
    inv(3)=i;
    con(3)=c;
    
    %we impose this restriction
    if LL_constr(2) > L
        error('fatal (steady_state_leverage) leverage restriction too high')
    end
    
    L=LL_constr(2);
    %this is the initial guess for Ntilde
    xNtilde=Ntilde;
    [util,biglambda,Ntilde,dtilde,pe,wtilde,kshock,kbar,i,h,c,lambdaz,rk,Rk,R,s,e] = oobserveL_Ntilde(xNtilde,lambdaf_p,Ttil_p,gam_p,L,xpe,lambdaw_p,psiL_p,sigmaL_p,abar_p,pi_p,h_guess, ...
        muzstar_p,upsil_p,alpha_p,phi_p,g,muup_p,beta_p,b_p,s,delta_p,bbar_p,gstar_p,bstar_p);
    L=(Ntilde+dtilde)/Ntilde;
    diff=util-yutil+(ye^2-e^2)/2;
    perc=100*(exp(diff)-1);    
    utility(4)=perc;
    sspread(4)=0;
    vvz(4)=0;
    kkbar(4)=kbar;
    hh(4)=h;
    aa(4)=Ntilde+dtilde;
    NN(4)=Ntilde;
    DD(4)=dtilde;
    nret(4)=kshock*Rk;
    dret(4)=(kshock*Rk-R)*(L-1);
    ret(4)=nret(4)+dret(4);
    RRk(4)=Rk;
    be(4)=kshock;
    gdp(4)=c+i+g;
    ppe(4)=pe;
    ut(4)=util-e^2/2;
    inv(4)=i;
    con(4)=c;
end
%this computes the steady state for the unobserved e model with a leverage
%restriction

xutil=log(xc-(b_p/muzstar_p)*xc)-psiL_p*xh^(1+sigmaL_p)/(1+sigmaL_p);
for ii = 1:length(LL_constr)
    L_constr=LL_constr(ii);
    [util,Ntilde,pe,e,s,R,dtilde,kbar,i,c,lambz,Rk,rk,h,Rdb,Rdg,vz,eta,biglambda,wtilde,ip] = find_Ntil(xNtil, ...
        xpe,sigmaL_p,psiL_p,lambdaw_p,alpha_p,b_p,g,h_guess,abar_p,bbar_p,Ttil_p,gam_p,muzstar_p,pi_p,L_constr,gstar_p, ...
        bstar_p,delta_p,upsil_p,phi_p,muup_p,beta_p,lambdaf_p);
    if ip==1
        utility(ii)=NaN;
        fprintf(' L_constr = %5.3f\n',L_constr)
        sspread(ii)=NaN;
        vvz(ii)=NaN;
        kkbar(ii)=NaN;
        hh(ii)=NaN;
        aa(ii)=NaN;
        NN(ii)=NaN;
        DD(ii)=NaN;
        kshock=NaN;
        nret(ii)=NaN;
        dret(ii)=NaN;
        ret(ii)=NaN;
        RRk(ii)=NaN;
        be(ii)=NaN;
        gdp(ii)=NaN;
        ut(ii)=NaN;
        inv(ii)=NaN;
        con(ii)=NaN;
    else
        diff=util-xutil+(xe^2-e^2)/2;
        perc=100*(exp(diff)-1);
        utility(ii)=perc;
        fprintf(' L_constr = %5.3f, utility = %9.7f\n',L_constr,perc)
        sspread(ii)=400*(Rdg-R);
        vvz(ii)=vz;
        kkbar(ii)=kbar;
        hh(ii)=h;
        aa(ii)=Ntilde+dtilde;
        NN(ii)=Ntilde;
        DD(ii)=dtilde;
        kshock=pe*exp(gstar_p)+(1-pe)*exp(bstar_p);
        nret(ii)=kshock*Rk;
        L=(Ntilde+dtilde)/Ntilde;
        dret(ii)=(kshock*Rk-R)*(L-1);
        ret(ii)=nret(ii)+dret(ii);
        RRk(ii)=Rk;
        be(ii)=kshock;
        gdp(ii)=c+i+g;
        ppe(ii)=pe;
        ut(ii)=util-e^2/2;
        inv(ii)=i;
        con(ii)=c;
    end
    fprintf(' run number %2i out of %2i\n',ii,length(LL_constr))
end
if length(LL_constr) > 1
    if length(LL_constr) == 2
        if tab == 1
            ttable
            disp(' table written, look for output in steady_state_results.tex')
        end
    end
    return
end
return
xkshock=xpe*exp(gstar_p)+(1-xpe)*exp(bstar_p);
kshock=pe*exp(gstar_p)+(1-pe)*exp(bstar_p);
L=(Ntilde+dtilde)/Ntilde;
xL=(xNtil+xdtil)/xNtil;
return_on_equity=kshock*Rk;
return_on_deposits=(kshock*Rk-R)*(L-1);
xreturn_on_equity=xkshock*xRk;
xreturn_on_deposits=(xkshock*xRk-R)*(xL-1);

xutil=log(xc-(b_p/muzstar_p)*xc)-psiL_p*xh^(1+sigmaL_p)/(1+sigmaL_p);
diff=util-xutil+(xe^2-e^2)/2;
perc=100*(exp(diff)-1);
fprintf(' unrestricted leverage = %5.3f, leverage restriction = %5.3f, ratio = %5.3f\n',L_cb,L_constr,L_constr/L_cb)
fprintf(' percent improvement in utility, going from no leverage to leverage = %5.3f\n',perc)
fprintf(' spread, Rdg - R, with leverage restriction = %5.3f, spread without it = %5.3f (all in APR)\n',400*(Rdg-R),400*(xRdg-xRe))
fprintf(' capital to labor ratio with and without leverage restriction = %5.3f, %5.3f\n',kbar/h,xkbar/xh)
fprintf(' biglambda = %5.3f, vz = %5.3f\n',biglambda,vz)
fprintf(' effort with and without leverage restriction = %5.3f, %5.3f\n',e,xe)
fprintf(' capital with and without leverage restriction = %5.3f, %5.3f\n',kbar,xkbar)
fprintf(' labor with and without leverage restriction = %5.3f, %5.3f\n',h,xh)
fprintf(' with  leverage retriction: return on bank equity, %5.3f, = portion due to bank equity, %5.3f, and to deposits, %5.3f, bank profits over gdp, %5.3f\n',return_on_equity+return_on_deposits,return_on_equity,return_on_deposits,(return_on_equity+return_on_deposits-1)*Ntilde/(c+i/muup_p+g))
fprintf(' w/out leverage retriction: return on bank equity, %5.3f, = portion due to bank equity, %5.3f, and to deposits, %5.3f, bank profits over gdp, %5.3f\n',xreturn_on_equity+xreturn_on_deposits,xreturn_on_equity,xreturn_on_deposits,(xreturn_on_equity+xreturn_on_deposits-1)*xNtil/(xc+xi/muup_p+xg))
fprintf(' gdp without leverage = %5.3f, with leverage = %5.3f\n',xc+xg+xi/muup_p,c+g+i/muup_p)
fprintf(' bank net worth without leverage = %5.3f, with leverage = %5.3f\n',xNtil,Ntilde)


1+1;
